Terms
=====

Terms is a `production rule system <https://en.wikipedia.org/wiki/Production_system>`_
that is used to build `expert <https://en.wikipedia.org/wiki/Expert_system>`_
and `knowledge representation and resoning <https://en.wikipedia.org/wiki/Knowledge_representation>`_ systems.

Documentation for the Terms projecct can be found `here <http://terms.readthedocs.org/>`_.

